# Author: Richard Fitzpatrick
# Modified from  http://matplotlib.org/examples/widgets/slider_demo.py
# Requires numpy and matplotlib

"""
Widget to illustrate how Fourier reconstruction of sawtooth waveform
depends on number terms included in series.

Last modified 18 Dec 2017.
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.widgets import Slider, Button
import matplotlib

from distutils.version import StrictVersion
if StrictVersion(matplotlib.__version__) > StrictVersion('2.0'):
    matplotlib.style.use('classic')

font = {'size' : 11}
matplotlib.rc('font', **font)

t = np.arange(0.0, 4.0, 0.001)

def gety(N):

   y = np.zeros_like(t)
   for n in range(N):
       nn = n+1
       y += -(2./np.pi)*np.sin(2.*np.pi*nn*t)/(1.*nn)

   return y    

# Generate initial plot
N0  = 4.
i   = int(round(N0))
y   = gety(i)

fig, ax = plt.subplots()
plt.subplots_adjust(left=0.20, bottom=0.30)
l,  = plt.plot(t, y,  lw=2, color='blue')
plt.axhline(y=0.,  lw=2, color='red', ls='dotted')
plt.axhline(y=1.,  lw=2, color='red', ls='dotted')
plt.axhline(y=-1., lw=2, color='red', ls='dotted')
plt.axis([0, 4., -1.25, 1.25])
plt.xlabel(r'$t/\tau$', size='large')
plt.ylabel(r'$y/A$', size='large')

# Generate slider
axcolor = 'lightgoldenrodyellow'
if StrictVersion(matplotlib.__version__) > StrictVersion('2.0'):
   axn = plt.axes([0.20, 0.15, 0.65, 0.03], facecolor=axcolor)
else:
   axn = plt.axes([0.20, 0.15, 0.65, 0.03], axisbg=axcolor)
sn = Slider(axn, r'$N$', 1., 64., valinit=N0, valfmt='%1.0f')

# Update plot using slider data
def update(val):
    N  = sn.val
    i  = int(round(N))
    l.set_ydata(gety(i))
    fig.canvas.draw_idle()
sn.on_changed(update)

# Generate reset button
resetax = plt.axes([0.8, 0.02, 0.1, 0.04])
button  = Button(resetax, 'Reset', color=axcolor, hovercolor='0.975')

def reset(event):
    sn.reset()
button.on_clicked(reset)

plt.show()
