# Author: Richard Fitzpatrick
# Modified from  http://matplotlib.org/examples/widgets/slider_demo.py
# Requires numpy and matplotlib

"""
Widget to illustrate near-field/far-field interference pattern
of circular disk normally illuminated by monochromatic light. 
Plots relative intensity of light versus normalized radial
distance v as function of normalized disk radius u.

Last modified 25 Jan 2018.
"""

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.widgets import Slider, Button
import scipy.special as sp
import sys
import matplotlib

from distutils.version import StrictVersion
if StrictVersion(matplotlib.__version__) > StrictVersion('2.0'):
    matplotlib.style.use('classic')

font = {'size' : 11}
matplotlib.rc('font', **font)

smax = 30

def U1 (u, v):
    r = u/v
    rat = r
    sgn = 1
    sum = 0.
    for s in range (0, smax):
        sum += sgn * rat * sp.jn(1+2*s, v)
        sgn *= -1
        rat *= r*r
        return sum

def U2 (u, v):
    r = u/v
    rat = r*r
    sgn = 1
    sum = 0.
    for s in range (0, smax):
        sum += sgn * rat * sp.jn(2+2*s, v)
        sgn *= -1
        rat *= r*r
    return sum

def V0 (u, v):
    r = v/u
    rat = 1
    sgn = 1
    sum = 0.
    for s in range (0, smax):
        sum += sgn * rat * sp.jn(2*s, v)
        sgn *= -1
        rat *= r*r
    return sum

def V1 (u, v):
    r = v/u
    rat = r
    sgn = 1
    sum = 0.
    for s in range (0, smax):
        sum += sgn * rat * sp.jn(1+2*s, v)
        sgn *= -1
        rat *= r*r
    return sum

def Intensity (u, vv, I):
    for v in vv:
        if (np.fabs(v) < u):
            v0 = V0(u, np.fabs(v))
            v1 = V1(u, np.fabs(v))
            I.append (v0*v0 + v1*v1)
        else:
            u1 = U1(u, np.fabs(v)) - np.sin((u*u+v*v)/2./u)
            u2 = U2(u, np.fabs(v)) - np.cos((u*u+v*v)/2./u)
            I.append (u1*u1 + u2*u2)            

# Generate plot
u_in    = input ("u ? ")
vmax_in = input ("vmax ? ")
imax_in = input ("imax ? ")
u    = float (u_in)
vmax = float (vmax_in)
imax = float (imax_in)
print (u, vmax, imax)
vv   = np.arange(-vmax,vmax,0.01)
I    = []
Intensity (u, vv, I)

fig = plt.figure()
plt.plot(vv, I, lw=2, color='red')
plt.axis([-vmax, vmax, 0., imax])
plt.xlabel(r'$u$', size='large')
plt.ylabel(r'${\cal I}/{\cal I}_0$', size='large')

plt.show()
